
local moduleName = "target"
local L = AceLibrary('AceLocale-2.2'):new('SimpleUnitFrames_Target')
local Target = SimpleUnitFrames:NewModule(moduleName, "AceEvent-2.0")

L:RegisterTranslations('enUS', function() return {

	["Target Frame"] = true,
	["Description"] = "Options for the target frame",
	["Health Text"] = true,
	["Mana Text"] = true,
	["Class Icon"] = true,	
	["Health Text Description"] = "Set health text to one of the formats",
	["Mana Text Description"] = "Set mama text to one of the formats",
	["Class Icon Description"] = "Toggle display of class icon",	
	
} end)

L:RegisterTranslations('koKR', function() return {

	["Target Frame"] = "대상 프레임",
	["Description"] = "대상 프레임에 대한 설정",
	["Health Text"] = "생명력 글자",
	["Mana Text"] = "마나 글자",
	["Health Text Description"] = "생명력 글자 표시 방법 선택",
	["Mana Text Description"] = "마나 글자 표시 방법 선택",
	
	
} end)

local icons = {
	BEAST = true,
	CRITTER = true,
	DEMON = true,
	DRAGONKIN = true,
	DRUID = true,
	ELEMENTAL = true,
	GIANT = true,
	HUMANOID = true,
	HUNTER = true,
	MAGE = true,
	MECHANICAL = true,
	PALADIN = true,
	PRIEST = true,
	ROGUE = true,
	SHAMAN = true,
	UNDEAD = true,
	UNKNOWN = true,
	WARLOCK = true,
	WARRIOR = true,
}



function Target:GetConsoleOptions()
	local OPTION_ORDER = 100
	return {
		type = 'group',
		name = L['Target Frame'],
		desc = L['Description'],
		args = {	
			hp = {
				order = OPTION_ORDER + 1,
				type = 'text',
				name = L['Health Text'],
				desc = L['Health Text Description'],
				get = function() return self.db.profile.hp end,
				set = function(v) 
								self.db.profile.hp = v
								self:UpdateHealth()
							end,
				validate = self.core.formatList,
			},
			mp = {
				order = OPTION_ORDER + 2,
				type = 'text',
				name = L['Mana Text'],
				desc = L['Mana Text Description'],
				get = function() return self.db.profile.mp end,
				set = function(v)
								self.db.profile.mp = v
								self:UpdateMana()
							end,
				validate = self.core.formatList,
			},
			class = {
				order = OPTION_ORDER + 5,
				type = 'toggle',
				name = L['Class Icon'],
				desc = L['Class Icon Description'],
				get = function() return self.db.profile.class end,
				set = function(v)
					self.db.profile.class = v
					if UnitExists('target') then
						self:UpdateClassIcon()
					end
				end
			}			
		}
	}

end

function Target:OnInitialize()	
	self.db = SimpleUnitFrames:AcquireDBNamespace(moduleName)

	SimpleUnitFrames:RegisterDefaults(moduleName, 'profile', {
		hp = "mh3completehp",
		mp = "currmaxmp",
		class = true,		
	} )
	
	TargetDeadText:SetText()

	-- If the FontStrings are created by TargetFrame, the text will layed below the name bar, so use a new frame.
	local frame = CreateFrame("Frame", nil, TargetFrame)
	frame:SetFrameLevel(TargetFrame:GetFrameLevel()+2)
	self.frame = frame
		
	-- Start to create our own FontStrings.
	local fontString
	
	-- Health Text.
	fontString = frame:CreateFontString(nil, "OVERLAY", "GameFontHighlightSmall")
	fontString:SetPoint("TOP", TargetFrameHealthBar, "TOP")
	fontString:SetText("Health")
	self.hpText = fontString
	
	-- Mana Text.
	fontString = frame:CreateFontString(nil, "OVERLAY", "GameFontHighlightSmall")
	fontString:SetPoint("TOP", TargetFrameManaBar, "TOP")
	fontString:SetText("Mana")
	self.mpText = fontString
	
end

function Target:OnEnable()
	self:RegisterEvent("UNIT_HEALTH", "OnHealthChange" )
	self:RegisterEvent("UNIT_MAXHEALTH", "OnHealthChange" )
	self:RegisterEvent("UNIT_MANA", "OnManaChange" )
	self:RegisterEvent("UNIT_MAXMANA", "OnManaChange")
	self:RegisterEvent("UNIT_ENERGY", "OnManaChange")
	self:RegisterEvent("UNIT_MAXENERGY", "OnManaChange")
	self:RegisterEvent("UNIT_RAGE", "OnManaChange")
	self:RegisterEvent("UNIT_MAXRAGE", "OnManaChange")
	self:RegisterEvent("UNIT_DISPLAYPOWER", "OnManaChange")
	self:RegisterEvent("PLAYER_TARGET_CHANGED")	
	self:Refresh()
end


function Target:PLAYER_TARGET_CHANGED()
	self:Refresh()
end

function Target:OnHealthChange(arg1)
	if arg1 == 'target' then
		self:UpdateHealth()
	end
end

function Target:OnManaChange(arg1)
	if arg1 == 'target' then
		self:UpdateMana()
	end
end

function Target:Refresh()
	if UnitExists('target') then
		self:UpdateHealth()
		self:UpdateMana()
		self:UpdateClassIcon()
	end
end
function Target:UpdateHealth()
	self.hpText:SetText( self:GetValueText('target', self.db.profile.hp) )
end

function Target:UpdateMana()
	self.mpText:SetText( self:GetValueText('target', self.db.profile.mp) )
end


function Target:UpdateClassIcon()
	
	local texture = self.texture
	
	if self.db.profile.class then
	
		if not texture then
			
			texture	= self.frame:CreateTexture("OVERLAY")
			texture:SetHeight(32)
			texture:SetWidth(32)
			texture:SetPoint("TOPRIGHT", TargetFrame, "TOPRIGHT", -85, -5)
			
			self.texture = texture
			
		end
		
		local icon
		if UnitIsPlayer('target') then
			_, icon = UnitClass('target')
		else
			icon = UnitCreatureType('target')
		end
		
		if not ( icon and icons[icon:upper()] ) then
			icon = "UNKNOWN"
		end
		
		texture:SetTexture("Interface\\AddOns\\SimpleUnitFrames\\Icons\\" .. icon .. ".tga")
		texture:Show()
		
	else
		
		if texture then
			texture:Hide()
		end
		
	end
	
end
